==> mediawiki-1.3.9.tar.gz: mediawiki-1.3.9/maintenance/wiktionary-interwiki.sql <==
-- For convenience, here are the *in-project* interwiki prefixes
-- for Wikipedia.

REPLACE INTO interwiki (iw_prefix,iw_url,iw_local) VALUES
('w','http://www.wikipedia.org/wiki/$1',1),
('m','http://meta.wikipedia.org/wiki/$1',1),
('meta','http://meta.wikipedia.org/wiki/$1',1),
('sep11','http://sep11.wikipedia.org/wiki/$1',1),
('simple','http://simple.wiktionary.org/wiki/$1',1),
('aa','http://aa.wiktionary.org/wiki/$1',1),
('ab','http://ab.wiktionary.org/wiki/$1',1),
('af','http://af.wiktionary.org/wiki/$1',1),
('als','http://als.wiktionary.org/wiki/$1',1),
('am','http://am.wiktionary.org/wiki/$1',1),
('ar','http://ar.wiktionary.org/wiki/$1',1),
('as','http://as.wiktionary.org/wiki/$1',1),
('ay','http://ay.wiktionary.org/wiki/$1',1),
('az','http://az.wiktionary.org/wiki/$1',1),
('ba','http://ba.wiktionary.org/wiki/$1',1),
('be','http://be.wiktionary.org/wiki/$1',1),
('bg','http://bg.wiktionary.org/wiki/$1',1),
('bh','http://bh.wiktionary.org/wiki/$1',1),
('bi','http://bi.wiktionary.org/wiki/$1',1),
('bn','http://bn.wiktionary.org/wiki/$1',1),
('bo','http://bo.wiktionary.org/wiki/$1',1),
('bs','http://bs.wiktionary.org/wiki/$1',1),
('ca','http://ca.wiktionary.org/wiki/$1',1),
('chr','http://chr.wiktionary.org/wiki/$1',1),
('co','http://co.wiktionary.org/wiki/$1',1),
('cs','http://cs.wiktionary.org/wiki/$1',1),
('csb','http://csb.wiktionary.org/wiki/$1',1),
('cy','http://cy.wiktionary.org/wiki/$1',1),
('da','http://da.wiktionary.org/wiki/$1',1),
('de','http://de.wiktionary.org/wiki/$1',1),
('dk','http://da.wiktionary.org/wiki/$1',1),
('dz','http://dz.wiktionary.org/wiki/$1',1),
('el','http://el.wiktionary.org/wiki/$1',1),
('en','http://en.wiktionary.org/wiki/$1',1),
('eo','http://eo.wiktionary.org/wiki/$1',1),
('es','http://es.wiktionary.org/wiki/$1',1),
('et','http://et.wiktionary.org/wiki/$1',1),
('eu','http://eu.wiktionary.org/wiki/$1',1),
('fa','http://fa.wiktionary.org/wiki/$1',1),
('fi','http://fi.wiktionary.org/wiki/$1',1),
('fj','http://fj.wiktionary.org/wiki/$1',1),
('fo','http://fo.wiktionary.org/wiki/$1',1),
('fr','http://fr.wiktionary.org/wiki/$1',1),
('fy','http://fy.wiktionary.org/wiki/$1',1),
('ga','http://ga.wiktionary.org/wiki/$1',1),
('gd','http://gd.wiktionary.org/wiki/$1',1),
('gl','http://gl.wiktionary.org/wiki/$1',1),
('gn','http://gn.wiktionary.org/wiki/$1',1),
('gu','http://gu.wiktionary.org/wiki/$1',1),
('gv','http://gv.wiktionary.org/wiki/$1',1),
('ha','http://ha.wiktionary.org/wiki/$1',1),
('he','http://he.wiktionary.org/wiki/$1',1),
('hi','http://hi.wiktionary.org/wiki/$1',1),
('hr','http://hr.wiktionary.org/wiki/$1',1),
('hu','http://hu.wiktionary.org/wiki/$1',1),
('hy','http://hy.wiktionary.org/wiki/$1',1),
('ia','http://ia.wiktionary.org/wiki/$1',1),
('id','http://id.wiktionary.org/wiki/$1',1),
('ik','http://ik.wiktionary.org/wiki/$1',1),
('io','http://io.wiktionary.org/wiki/$1',1),
('is','http://is.wiktionary.org/wiki/$1',1),
('it','http://it.wiktionary.org/wiki/$1',1),
('iu','http://iu.wiktionary.org/wiki/$1',1),
('ja','http://ja.wiktionary.org/wiki/$1',1),
('jv','http://jv.wiktionary.org/wiki/$1',1),
('ka','http://ka.wiktionary.org/wiki/$1',1),
('kk','http://kk.wiktionary.org/wiki/$1',1),
('kl','http://kl.wiktionary.org/wiki/$1',1),
('km','http://km.wiktionary.org/wiki/$1',1),
('kn','http://kn.wiktionary.org/wiki/$1',1),
('ko','http://ko.wiktionary.org/wiki/$1',1),
('ks','http://ks.wiktionary.org/wiki/$1',1),
('ku','http://ku.wiktionary.org/wiki/$1',1),
('ky','http://ky.wiktionary.org/wiki/$1',1),
('la','http://la.wiktionary.org/wiki/$1',1),
('lo','http://lo.wiktionary.org/wiki/$1',1),
('lt','http://lt.wiktionary.org/wiki/$1',1),
('lv','http://lv.wiktionary.org/wiki/$1',1),
('mg','http://mg.wiktionary.org/wiki/$1',1),
('mi','http://mi.wiktionary.org/wiki/$1',1),
('mk','http://mk.wiktionary.org/wiki/$1',1),
('ml','http://ml.wiktionary.org/wiki/$1',1),
('mn','http://mn.wiktionary.org/wiki/$1',1),
('mo','http://mo.wiktionary.org/wiki/$1',1),
('mr','http://mr.wiktionary.org/wiki/$1',1),
('ms','http://ms.wiktionary.org/wiki/$1',1),
('my','http://my.wiktionary.org/wiki/$1',1),
('na','http://na.wiktionary.org/wiki/$1',1),
('nah','http://nah.wiktionary.org/wiki/$1',1),
('nb', 'http://no.wiktionary.org/wiki/$1',1),
('nds','http://nds.wiktionary.org/wiki/$1',1),
('ne','http://ne.wiktionary.org/wiki/$1',1),
('nl','http://nl.wiktionary.org/wiki/$1',1),
('no','http://no.wiktionary.org/wiki/$1',1),
('oc','http://oc.wiktionary.org/wiki/$1',1),
('om','http://om.wiktionary.org/wiki/$1',1),
('or','http://or.wiktionary.org/wiki/$1',1),
('pa','http://pa.wiktionary.org/wiki/$1',1),
('pl','http://pl.wiktionary.org/wiki/$1',1),
('ps','http://ps.wiktionary.org/wiki/$1',1),
('pt','http://pt.wiktionary.org/wiki/$1',1),
('qu','http://qu.wiktionary.org/wiki/$1',1),
('rm','http://rm.wiktionary.org/wiki/$1',1),
('rn','http://rn.wiktionary.org/wiki/$1',1),
('ro','http://ro.wiktionary.org/wiki/$1',1),
('ru','http://ru.wiktionary.org/wiki/$1',1),
('rw','http://rw.wiktionary.org/wiki/$1',1),
('sa','http://sa.wiktionary.org/wiki/$1',1),
('sd','http://sd.wiktionary.org/wiki/$1',1),
('sg','http://sg.wiktionary.org/wiki/$1',1),
('sh','http://sh.wiktionary.org/wiki/$1',1),
('si','http://si.wiktionary.org/wiki/$1',1),
('sk','http://sk.wiktionary.org/wiki/$1',1),
('sl','http://sl.wiktionary.org/wiki/$1',1),
('sm','http://sm.wiktionary.org/wiki/$1',1),
('sn','http://sn.wiktionary.org/wiki/$1',1),
('so','http://so.wiktionary.org/wiki/$1',1),
('sq','http://sq.wiktionary.org/wiki/$1',1),
('sr','http://sr.wiktionary.org/wiki/$1',1),
('ss','http://ss.wiktionary.org/wiki/$1',1),
('st','http://st.wiktionary.org/wiki/$1',1),
('su','http://su.wiktionary.org/wiki/$1',1),
('sv','http://sv.wiktionary.org/wiki/$1',1),
('sw','http://sw.wiktionary.org/wiki/$1',1),
('ta','http://ta.wiktionary.org/wiki/$1',1),
('te','http://te.wiktionary.org/wiki/$1',1),
('tg','http://tg.wiktionary.org/wiki/$1',1),
('th','http://th.wiktionary.org/wiki/$1',1),
('ti','http://ti.wiktionary.org/wiki/$1',1),
('tk','http://tk.wiktionary.org/wiki/$1',1),
('tl','http://tl.wiktionary.org/wiki/$1',1),
('tn','http://tn.wiktionary.org/wiki/$1',1),
('to','http://to.wiktionary.org/wiki/$1',1),
('tokipona','http://tokipona.wiktionary.org/wiki/$1',1),
('tpi','http://tpi.wiktionary.org/wiki/$1',1),
('tr','http://tr.wiktionary.org/wiki/$1',1),
('ts','http://ts.wiktionary.org/wiki/$1',1),
('tt','http://tt.wiktionary.org/wiki/$1',1),
('tw','http://tw.wiktionary.org/wiki/$1',1),
('ug','http://ug.wiktionary.org/wiki/$1',1),
('uk','http://uk.wiktionary.org/wiki/$1',1),
('ur','http://ur.wiktionary.org/wiki/$1',1),
('uz','http://uz.wiktionary.org/wiki/$1',1),
('vi','http://vi.wiktionary.org/wiki/$1',1),
('vo','http://vo.wiktionary.org/wiki/$1',1),
('wa','http://wa.wiktionary.org/wiki/$1',1),
('wo','http://wo.wiktionary.org/wiki/$1',1),
('xh','http://xh.wiktionary.org/wiki/$1',1),
('yi','http://yi.wiktionary.org/wiki/$1',1),
('yo','http://yo.wiktionary.org/wiki/$1',1),
('za','http://za.wiktionary.org/wiki/$1',1),
('zh','http://zh.wiktionary.org/wiki/$1',1),
('zh-cn','http://zh.wiktionary.org/wiki/$1',1),
('zh-tw','http://zh.wiktionary.org/wiki/$1',1),
('zu','http://zu.wiktionary.org/wiki/$1',1);

==> mediawiki_1.12.0.orig.tar.gz: mediawiki-1.12.0/maintenance/wiktionary-interwiki.sql <==
-- For convenience, here are the *in-project* interwiki prefixes
-- for Wikipedia.

REPLACE INTO /*$wgDBprefix*/interwiki (iw_prefix,iw_url,iw_local) VALUES
('w','http://www.wikipedia.org/wiki/$1',1),
('m','http://meta.wikipedia.org/wiki/$1',1),
('meta','http://meta.wikipedia.org/wiki/$1',1),
('sep11','http://sep11.wikipedia.org/wiki/$1',1),
('simple','http://simple.wiktionary.org/wiki/$1',1),
('aa','http://aa.wiktionary.org/wiki/$1',1),
('ab','http://ab.wiktionary.org/wiki/$1',1),
('af','http://af.wiktionary.org/wiki/$1',1),
('als','http://als.wiktionary.org/wiki/$1',1),
('am','http://am.wiktionary.org/wiki/$1',1),
('ar','http://ar.wiktionary.org/wiki/$1',1),
('as','http://as.wiktionary.org/wiki/$1',1),
('ay','http://ay.wiktionary.org/wiki/$1',1),
('az','http://az.wiktionary.org/wiki/$1',1),
('ba','http://ba.wiktionary.org/wiki/$1',1),
('be','http://be.wiktionary.org/wiki/$1',1),
('bg','http://bg.wiktionary.org/wiki/$1',1),
('bh','http://bh.wiktionary.org/wiki/$1',1),
('bi','http://bi.wiktionary.org/wiki/$1',1),
('bn','http://bn.wiktionary.org/wiki/$1',1),
('bo','http://bo.wiktionary.org/wiki/$1',1),
('bs','http://bs.wiktionary.org/wiki/$1',1),
('ca','http://ca.wiktionary.org/wiki/$1',1),
('chr','http://chr.wiktionary.org/wiki/$1',1),
('co','http://co.wiktionary.org/wiki/$1',1),
('cs','http://cs.wiktionary.org/wiki/$1',1),
('csb','http://csb.wiktionary.org/wiki/$1',1),
('cy','http://cy.wiktionary.org/wiki/$1',1),
('da','http://da.wiktionary.org/wiki/$1',1),
('de','http://de.wiktionary.org/wiki/$1',1),
('dk','http://da.wiktionary.org/wiki/$1',1),
('dz','http://dz.wiktionary.org/wiki/$1',1),
('el','http://el.wiktionary.org/wiki/$1',1),
('en','http://en.wiktionary.org/wiki/$1',1),
('eo','http://eo.wiktionary.org/wiki/$1',1),
('es','http://es.wiktionary.org/wiki/$1',1),
('et','http://et.wiktionary.org/wiki/$1',1),
('eu','http://eu.wiktionary.org/wiki/$1',1),
('fa','http://fa.wiktionary.org/wiki/$1',1),
('fi','http://fi.wiktionary.org/wiki/$1',1),
('fj','http://fj.wiktionary.org/wiki/$1',1),
('fo','http://fo.wiktionary.org/wiki/$1',1),
('fr','http://fr.wiktionary.org/wiki/$1',1),
('fy','http://fy.wiktionary.org/wiki/$1',1),
('ga','http://ga.wiktionary.org/wiki/$1',1),
('gd','http://gd.wiktionary.org/wiki/$1',1),
('gl','http://gl.wiktionary.org/wiki/$1',1),
('gn','http://gn.wiktionary.org/wiki/$1',1),
('gu','http://gu.wiktionary.org/wiki/$1',1),
('gv','http://gv.wiktionary.org/wiki/$1',1),
('ha','http://ha.wiktionary.org/wiki/$1',1),
('he','http://he.wiktionary.org/wiki/$1',1),
('hi','http://hi.wiktionary.org/wiki/$1',1),
('hr','http://hr.wiktionary.org/wiki/$1',1),
('hu','http://hu.wiktionary.org/wiki/$1',1),
('hy','http://hy.wiktionary.org/wiki/$1',1),
('ia','http://ia.wiktionary.org/wiki/$1',1),
('id','http://id.wiktionary.org/wiki/$1',1),
('ik','http://ik.wiktionary.org/wiki/$1',1),
('io','http://io.wiktionary.org/wiki/$1',1),
('is','http://is.wiktionary.org/wiki/$1',1),
('it','http://it.wiktionary.org/wiki/$1',1),
('iu','http://iu.wiktionary.org/wiki/$1',1),
('ja','http://ja.wiktionary.org/wiki/$1',1),
('jv','http://jv.wiktionary.org/wiki/$1',1),
('ka','http://ka.wiktionary.org/wiki/$1',1),
('kk','http://kk.wiktionary.org/wiki/$1',1),
('kl','http://kl.wiktionary.org/wiki/$1',1),
('km','http://km.wiktionary.org/wiki/$1',1),
('kn','http://kn.wiktionary.org/wiki/$1',1),
('ko','http://ko.wiktionary.org/wiki/$1',1),
('ks','http://ks.wiktionary.org/wiki/$1',1),
('ku','http://ku.wiktionary.org/wiki/$1',1),
('ky','http://ky.wiktionary.org/wiki/$1',1),
('la','http://la.wiktionary.org/wiki/$1',1),
('lo','http://lo.wiktionary.org/wiki/$1',1),
('lt','http://lt.wiktionary.org/wiki/$1',1),
('lv','http://lv.wiktionary.org/wiki/$1',1),
('mg','http://mg.wiktionary.org/wiki/$1',1),
('mi','http://mi.wiktionary.org/wiki/$1',1),
('mk','http://mk.wiktionary.org/wiki/$1',1),
('ml','http://ml.wiktionary.org/wiki/$1',1),
('mn','http://mn.wiktionary.org/wiki/$1',1),
('mo','http://mo.wiktionary.org/wiki/$1',1),
('mr','http://mr.wiktionary.org/wiki/$1',1),
('ms','http://ms.wiktionary.org/wiki/$1',1),
('my','http://my.wiktionary.org/wiki/$1',1),
('na','http://na.wiktionary.org/wiki/$1',1),
('nah','http://nah.wiktionary.org/wiki/$1',1),
('nb', 'http://no.wiktionary.org/wiki/$1',1),
('nds','http://nds.wiktionary.org/wiki/$1',1),
('ne','http://ne.wiktionary.org/wiki/$1',1),
('nl','http://nl.wiktionary.org/wiki/$1',1),
('no','http://no.wiktionary.org/wiki/$1',1),
('oc','http://oc.wiktionary.org/wiki/$1',1),
('om','http://om.wiktionary.org/wiki/$1',1),
('or','http://or.wiktionary.org/wiki/$1',1),
('pa','http://pa.wiktionary.org/wiki/$1',1),
('pl','http://pl.wiktionary.org/wiki/$1',1),
('ps','http://ps.wiktionary.org/wiki/$1',1),
('pt','http://pt.wiktionary.org/wiki/$1',1),
('qu','http://qu.wiktionary.org/wiki/$1',1),
('rm','http://rm.wiktionary.org/wiki/$1',1),
('rn','http://rn.wiktionary.org/wiki/$1',1),
('ro','http://ro.wiktionary.org/wiki/$1',1),
('ru','http://ru.wiktionary.org/wiki/$1',1),
('rw','http://rw.wiktionary.org/wiki/$1',1),
('sa','http://sa.wiktionary.org/wiki/$1',1),
('sd','http://sd.wiktionary.org/wiki/$1',1),
('sg','http://sg.wiktionary.org/wiki/$1',1),
('sh','http://sh.wiktionary.org/wiki/$1',1),
('si','http://si.wiktionary.org/wiki/$1',1),
('sk','http://sk.wiktionary.org/wiki/$1',1),
('sl','http://sl.wiktionary.org/wiki/$1',1),
('sm','http://sm.wiktionary.org/wiki/$1',1),
('sn','http://sn.wiktionary.org/wiki/$1',1),
('so','http://so.wiktionary.org/wiki/$1',1),
('sq','http://sq.wiktionary.org/wiki/$1',1),
('sr','http://sr.wiktionary.org/wiki/$1',1),
('ss','http://ss.wiktionary.org/wiki/$1',1),
('st','http://st.wiktionary.org/wiki/$1',1),
('su','http://su.wiktionary.org/wiki/$1',1),
('sv','http://sv.wiktionary.org/wiki/$1',1),
('sw','http://sw.wiktionary.org/wiki/$1',1),
('ta','http://ta.wiktionary.org/wiki/$1',1),
('te','http://te.wiktionary.org/wiki/$1',1),
('tg','http://tg.wiktionary.org/wiki/$1',1),
('th','http://th.wiktionary.org/wiki/$1',1),
('ti','http://ti.wiktionary.org/wiki/$1',1),
('tk','http://tk.wiktionary.org/wiki/$1',1),
('tl','http://tl.wiktionary.org/wiki/$1',1),
('tn','http://tn.wiktionary.org/wiki/$1',1),
('to','http://to.wiktionary.org/wiki/$1',1),
('tokipona','http://tokipona.wiktionary.org/wiki/$1',1),
('tpi','http://tpi.wiktionary.org/wiki/$1',1),
('tr','http://tr.wiktionary.org/wiki/$1',1),
('ts','http://ts.wiktionary.org/wiki/$1',1),
('tt','http://tt.wiktionary.org/wiki/$1',1),
('tw','http://tw.wiktionary.org/wiki/$1',1),
('ug','http://ug.wiktionary.org/wiki/$1',1),
('uk','http://uk.wiktionary.org/wiki/$1',1),
('ur','http://ur.wiktionary.org/wiki/$1',1),
('uz','http://uz.wiktionary.org/wiki/$1',1),
('vi','http://vi.wiktionary.org/wiki/$1',1),
('vo','http://vo.wiktionary.org/wiki/$1',1),
('wa','http://wa.wiktionary.org/wiki/$1',1),
('wo','http://wo.wiktionary.org/wiki/$1',1),
('xh','http://xh.wiktionary.org/wiki/$1',1),
('yi','http://yi.wiktionary.org/wiki/$1',1),
('yo','http://yo.wiktionary.org/wiki/$1',1),
('za','http://za.wiktionary.org/wiki/$1',1),
('zh','http://zh.wiktionary.org/wiki/$1',1),
('zh-cn','http://zh.wiktionary.org/wiki/$1',1),
('zh-tw','http://zh.wiktionary.org/wiki/$1',1),
('zu','http://zu.wiktionary.org/wiki/$1',1);
